@@ -204,11 +204,11 @@ pub fn map_extents(fd: &File) -> Result<Option<Vec<Extent>>> {
 /// start and end of the data segment.
 // FIXME: Should work on *BSD too?
 pub fn next_sparse_segments(infd: &File, outfd: &File, pos: u64) -> Result<(u64, u64)> {
-    let next_data = match lseek(infd, SeekFrom::Data(pos as i64))? {
+    let next_data = match lseek(infd, SeekFrom::Data(pos))? {
         SeekOff::Offset(off) => off,
         SeekOff::EOF => infd.metadata()?.len(),
     };
-    let next_hole = match lseek(infd, SeekFrom::Hole(next_data as i64))? {
+    let next_hole = match lseek(infd, SeekFrom::Hole(next_data))? {
         SeekOff::Offset(off) => off,
         SeekOff::EOF => infd.metadata()?.len(),
     };
@@ -376,7 +376,7 @@ mod tests {
         {
             let mut fd = OpenOptions::new().write(true).append(false).open(&file)?;
             let s = "x".repeat(512*1024);
-            fd.write(s.as_bytes())?;
+            fd.write_all(s.as_bytes())?;
             assert!(probably_sparse(&fd)?);
         }
 
@@ -674,8 +674,8 @@ mod tests {
         assert!(extents_p.is_some());
         let extents = extents_p.unwrap();
         assert_eq!(extents.len(), 1);
-        assert_eq!(extents[0].start, offset as u64);
-        assert_eq!(extents[0].end, offset as u64 + 4 * 1024); // FIXME: Assume 4k blocks
+        assert_eq!(extents[0].start, offset);
+        assert_eq!(extents[0].end, offset + 4 * 1024); // FIXME: Assume 4k blocks
         assert!(!extents[0].shared);
 
         Ok(())
@@ -695,7 +695,7 @@ mod tests {
         let fsize = 1024 * 1024;
         // FIXME: Assumes 4k blocks
         let bsize = 4 * 1024;
-        let block = iter::repeat(0xff_u8).take(bsize).collect::<Vec<u8>>();
+        let block = iter::repeat_n(0xff_u8, bsize).collect::<Vec<u8>>();
 
         let mut fd = OpenOptions::new().write(true).append(false).open(&file)?;
         // Skip every-other block
@@ -731,7 +731,7 @@ mod tests {
         let extents = extents_p.unwrap();
 
         assert_eq!(1, extents.len());
-        assert_eq!(0 as u64, extents[0].start);
+        assert_eq!(0u64, extents[0].start);
         assert_eq!(size as u64, extents[0].end);
 
         Ok(())
